@@ -45,31 +45,26 @@ int KBEffect::m_numKBEffectRepeated = 0;
 KBEffect::KBEffect(SlideShowKB *parent, bool needFadeIn)
 {
 
-    this->slideWidget = parent;
-    this->m_needFadeIn  = needFadeIn;
+    this->slideWidget  = parent;
+    this->m_needFadeIn = needFadeIn;
 }
 
-
 KBEffect::~KBEffect()
 {
-
 }
 
-
 void KBEffect::setupNewImage(int img)
 {
 
     slideWidget->setupNewImage(img);
 }
 
-
 void KBEffect::swapImages()
 {
 
     slideWidget->swapImages();
 }
 
-
 Image *KBEffect::image(int img)
 {
 
@@ -77,7 +72,6 @@ Image *KBEffect::image(int img)
     return slideWidget->m_image[img];
 }
 
-
 KBEffect::Type KBEffect::chooseKBEffect(KBEffect::Type oldType)
 {
 
@@ -97,8 +91,6 @@ KBEffect::Type KBEffect::chooseKBEffect(KBEffect::Type oldType)
     return type;
 }
 
-
-
 // -------------------------------------------------------------------------
 
 FadeKBEffect::FadeKBEffect(SlideShowKB *parent, bool needFadeIn):
@@ -107,13 +99,10 @@ FadeKBEffect::FadeKBEffect(SlideShowKB *parent, bool needFadeIn):
     m_img[0] = image(0);
 }
 
-
 FadeKBEffect::~FadeKBEffect()
 {
-
 }
 
-
 bool FadeKBEffect::done()
 {
 
@@ -126,7 +115,6 @@ bool FadeKBEffect::done()
     return false;
 }
 
-
 void FadeKBEffect::advanceTime(float step)
 {
 
@@ -145,20 +133,17 @@ void FadeKBEffect::advanceTime(float step)
 
 // -------------------------------------------------------------------------
 
-BlendKBEffect::BlendKBEffect(SlideShowKB *parent, bool needFadeIn):
-        KBEffect(parent, needFadeIn)
+BlendKBEffect::BlendKBEffect(SlideShowKB *parent, bool needFadeIn)
+             : KBEffect(parent, needFadeIn)
 {
     m_img[0] = image(0);
     m_img[1] = 0;
 }
 
-
 BlendKBEffect::~BlendKBEffect()
 {
-
 }
 
-
 bool BlendKBEffect::done()
 {
 
@@ -172,10 +157,8 @@ bool BlendKBEffect::done()
     return false;
 }
 
-
 void BlendKBEffect::advanceTime(float step)
 {
-
     m_img[0]->m_pos += step;
 
     if (m_img[0]->m_pos >= 1.0)
@@ -189,7 +172,6 @@ void BlendKBEffect::advanceTime(float step)
 
     else if (m_img[0]->m_pos > 0.9)
     {
-
         m_img[0]->m_opacity = (1.0 - m_img[0]->m_pos) * 10;
 
         if (m_img[1] == 0)
@@ -198,10 +180,11 @@ void BlendKBEffect::advanceTime(float step)
             m_img[1] = image(1);
             m_img[1]->m_opacity = 1.0;
         }
-
     }
     else
+    {
         m_img[0]->m_opacity = 1.0;
+    }
 }
 
 }  // namespace KIPIAdvancedSlideshowPlugin
