@@ -10,7 +10,7 @@
  *
  * Parts of this code are based on
  * smoothslidesaver by Carsten Weinhold <carsten dot weinhold at gmx dot de>
- * and slideshowgl by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * and slideshowgl by Renchi Raju <renchi dot raju at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -54,7 +54,11 @@
 
 // Local includes
 
+#include "commoncontainer.h"
 #include "imageloadthread.h"
+#include "kbeffect.h"
+#include "playbackwidget.h"
+#include "screenproperties.h"
 
 namespace KIPIAdvancedSlideshowPlugin
 {
@@ -157,18 +161,18 @@ Image::~Image()
 // -------------------------------------------------------------------------
 
 SlideShowKB::SlideShowKB(const QList<QPair<QString, int> >& fileList,
-                         const QStringList& commentsList, SharedData* sharedData)
-        : QGLWidget()
+                         const QStringList& commentsList, SharedContainer* sharedData)
+           : QGLWidget()
 {
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowFlags(Qt::X11BypassWindowManagerHint |
                    Qt::WindowStaysOnTopHint | Qt::Popup);
 
     QRect deskRect = KGlobalSettings::desktopGeometry(this);
-    m_deskX      = deskRect.x();
-    m_deskY      = deskRect.y();
-    m_deskWidth  = deskRect.width();
-    m_deskHeight = deskRect.height();
+    m_deskX        = deskRect.x();
+    m_deskY        = deskRect.y();
+    m_deskWidth    = deskRect.width();
+    m_deskHeight   = deskRect.height();
 
     move(m_deskX, m_deskY);
     resize(m_deskWidth, m_deskHeight);
@@ -210,10 +214,10 @@ SlideShowKB::SlideShowKB(const QList<QPair<QString, int> >& fileList,
     m_endOfShow       = false;
     m_showingEnd      = false;
 
-    connect(m_timer, SIGNAL(timeout(void)),
+    connect(m_timer, SIGNAL(timeout()),
             this, SLOT(moveSlot()));
 
-    connect(m_imageLoadThread, SIGNAL(endOfShow(void)),
+    connect(m_imageLoadThread, SIGNAL(signalEndOfShow()),
             this, SLOT(slotEndOfShow()));
 
     // -- hide cursor when not moved --------------------
@@ -328,7 +332,7 @@ bool SlideShowKB::setupNewImage(int idx)
         // we have the image lock and there is an image
         float imageAspect    = m_imageLoadThread->imageAspect();
         ViewTrans *viewTrans = new ViewTrans(m_zoomIn, aspect() / imageAspect);
-        m_image[idx]           = new Image(viewTrans, imageAspect);
+        m_image[idx]         = new Image(viewTrans, imageAspect);
 
         applyTexture(m_image[idx], m_imageLoadThread->image());
         ok = true;
