@@ -41,9 +41,9 @@ class BatchProcessImagesList : public QTreeWidget
 
 public:
 
-    BatchProcessImagesList(QWidget *parent=0);
+    BatchProcessImagesList(QWidget *parent = 0);
 
-signals:
+Q_SIGNALS:
 
     void addedDropItems(QStringList filesPath);
 
