@@ -6,7 +6,7 @@
  * Date        : 2003-11-03
  * Description : calendar parameters.
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2007-2008 by Orgad Shaneh <orgads at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -68,6 +68,8 @@ public:
     int                year;
 };
 
+// ---------------------------------------------------------------------------
+
 class CalSettings : public QObject
 {
     Q_OBJECT
@@ -94,11 +96,11 @@ public:
 
     CalParams params;
 
-signals:
+Q_SIGNALS:
 
     void settingsChanged();
 
-public slots:
+public Q_SLOTS:
 
     void setPaperSize(const QString &paperSize);
     void setImagePos(int pos);
