@@ -71,7 +71,7 @@ class SimpleViewerPriv
 {
 public:
 
-    SimpleViewerPriv() : maxThumbSize(45), viewer("viewer.swf")
+    SimpleViewerPriv() : maxThumbSize(45), viewer("web/svcore/swf/simpleviewer.swf")
     {
         configDlg    = 0;
         totalActions = 0;
@@ -113,7 +113,7 @@ SimpleViewer::SimpleViewer(KIPI::Interface* interface, QObject *parent)
     d->interface = interface;
 
     d->simpleViewerFiles.append(d->viewer);
-    d->simpleViewerFiles.append("swfobject.js");
+    d->simpleViewerFiles.append("web/svcore/js/swfobject.js");
     d->hostName = KGlobal::mainComponent().aboutData()->programName();
     d->hostUrl  = KGlobal::mainComponent().aboutData()->homepage();
 
