@@ -267,7 +267,7 @@ IPTCEnvelope::IPTCEnvelope(QWidget* parent)
     // --------------------------------------------------------
 
     QLabel *note = new QLabel(i18n("<b>Note: "
-                 "<b><a href='http://en.wikipedia.org/wiki/IPTC'>IPTC</a></b> "
+                 "<b><a href='http://en.wikipedia.org/wiki/IPTC_Information_Interchange_Model'>IPTC</a></b> "
                  "text tags only support the printable "
                  "<b><a href='http://en.wikipedia.org/wiki/Ascii'>ASCII</a></b> "
                  "characters and limit string sizes. "
