@@ -674,7 +674,7 @@ void BatchDialog::processed(const KUrl& url, const QString& tmpFile)
 
             KIPI::ImageInfo orgInfo = d->iface->info(url);
             KIPI::ImageInfo newInfo = d->iface->info(KUrl(destFile));
-            newInfo.cloneData(orgInfo);
+            orgInfo.cloneData(newInfo);
         }
     }
 
