@@ -7,7 +7,7 @@
  * Description : a kipi plugin to convert Raw file in single 
  *               or batch mode.
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -35,17 +35,23 @@
 
 class KAction;
 
+namespace KIPIRawConverterPlugin
+{
+    class SingleDialog;
+    class BatchDialog;
+}
+
 class Plugin_RawConverter : public KIPI::Plugin
 {
     Q_OBJECT
 
 public:
 
-    Plugin_RawConverter(QObject *parent, const QVariantList &args);
+    Plugin_RawConverter(QObject *parent, const QVariantList& args);
     ~Plugin_RawConverter();
 
-    KIPI::Category category( KAction* action ) const;
-    void setup( QWidget* widget );
+    KIPI::Category category(KAction* action) const;
+    void setup(QWidget* widget);
 
 private:
 
@@ -59,8 +65,11 @@ private Q_SLOTS:
 
 private:
 
-    KAction *m_singleAction;
-    KAction *m_batchAction;
+    KAction                              *m_singleAction;
+    KAction                              *m_batchAction;
+
+    KIPIRawConverterPlugin::SingleDialog *m_singleDlg;
+    KIPIRawConverterPlugin::BatchDialog  *m_batchDlg;
 };
 
 #endif /* PLUGIN_RAWCONVERTER_H */
