@@ -55,7 +55,7 @@ struct SimpleSettingsPriv
 };
 
 SimpleSettings::SimpleSettings(QWidget* parent)
-              : QWidget(parent), d(new SimpleSettingsPriv)
+    : QWidget(parent), d(new SimpleSettingsPriv)
 {
     d->settingsSlider = new QSlider(Qt::Vertical);
     d->settingsSlider->setRange(0, 2);
@@ -82,7 +82,7 @@ SimpleSettings::SimpleSettings(QWidget* parent)
                         "   background: #cccccc;"
                         "   margin: 0 -8px; /* expand outside the groove */"
                         "}"
-    );
+                       );
     d->settingsSlider->setStyleSheet(sliderStyle);
 
     QLabel* lSlow = new QLabel(i18n("<p><b>Slower<br/>(low-res / slightly blurred images)</b></p>"
@@ -103,14 +103,20 @@ SimpleSettings::SimpleSettings(QWidget* parent)
     lStd->setWordWrap(true);
     lFast->setWordWrap(true);
 
-    // FIXME: since I'm not able to use the same object twice
-    //        in a layout, I need two labels here
+    // --------------------------------------------------------
+
+    const QString colorStyle("background: #999999;");
+    const unsigned int maxColorLabelHeight = 1;
+
     QLabel* coloredSpacer = new QLabel;
-    coloredSpacer->setStyleSheet("background: #999999;");
-    coloredSpacer->setMaximumHeight(1);
+    coloredSpacer->setStyleSheet(colorStyle);
+    coloredSpacer->setMaximumHeight(maxColorLabelHeight);
+
     QLabel* coloredSpacer2 = new QLabel;
-    coloredSpacer2->setStyleSheet("background: #999999;");
-    coloredSpacer2->setMaximumHeight(1);
+    coloredSpacer2->setStyleSheet(colorStyle);
+    coloredSpacer2->setMaximumHeight(maxColorLabelHeight);
+
+    // --------------------------------------------------------
 
     QGridLayout* sliderLayout = new QGridLayout;
     sliderLayout->addWidget(d->settingsSlider,  0, 0, 5, 1);
@@ -165,6 +171,7 @@ void SimpleSettings::simpleModeChanged(int value)
             d->settings.neighborGroups = 2;
             break;
     }
+
     d->settings.simpleMode = value;
 }
 
