@@ -35,7 +35,7 @@
 
 // KDE includes
 
-#include <KDebug>
+#include <kdebug.h>
 #include <KConfig>
 #include <KLocale>
 #include <KMenu>
@@ -56,10 +56,6 @@
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
-#if KDCRAW_VERSION < 0x000400
-#include <libkdcraw/dcrawbinary.h>
-#endif
-
 // LibKIPI includes
 
 #include <libkipi/interface.h>
@@ -550,11 +546,7 @@ void SwWindow::uploadNextPhoto()
     QString imgPath = m_transferQueue.first().path();
 
     // check if we have to RAW file -> use preview image then
-#if KDCRAW_VERSION < 0x000400
-    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
-#else
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-#endif
     QFileInfo fileInfo(imgPath);
     QString caption;
     bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
